searchData={"items":[{"type":"module","title":"Validate","doc":"Validate, validate incoming requests in an easy to reason-about way.","ref":"Validate.html"},{"type":"function","title":"Validate.validate/2","doc":"Validates an input against a given list of rules","ref":"Validate.html#validate/2"},{"type":"function","title":"Examples - Validate.validate/2","doc":"iex> {:ok, _data} = Validate.validate(\"Jane\", required: true, type: :string)\n    iex> {:error, _errors} = Validate.validate([], required: true, type: :list)\n    iex> {:ok, _data} = Validate.validate(%{\"name\" => \"Jane\"}, %{\"name\" => [required: true, type: :string]})","ref":"Validate.html#validate/2-examples"},{"type":"module","title":"Validate.Plugs.FormRequest","doc":"","ref":"Validate.Plugs.FormRequest.html"},{"type":"module","title":"Validate.Rules.DateString","doc":"","ref":"Validate.Rules.DateString.html"},{"type":"function","title":"Validate.Rules.DateString.validate/1","doc":"","ref":"Validate.Rules.DateString.html#validate/1"},{"type":"module","title":"Validate.Util","doc":"Utilities to help with validation","ref":"Validate.Util.html"},{"type":"function","title":"Validate.Util.errors_to_map/1","doc":"Turns an array of %Validate.Validator.Error{} structs into a keyed map of errors","ref":"Validate.Util.html#errors_to_map/1"},{"type":"function","title":"Examples - Validate.Util.errors_to_map/1","doc":"iex> {:error, errors} = Validate.validate(%{\"name\" => \"\"}, %{\"name\" => [required: true]})\n    iex> %{\"name\" => [\"is required\"]} == Validate.Util.errors_to_map(errors)","ref":"Validate.Util.html#errors_to_map/1-examples"},{"type":"module","title":"Validate.Validator","doc":"Provides the Error and Arg structs, as well as helpers for validation responses","ref":"Validate.Validator.html"},{"type":"function","title":"Validate.Validator.error/1","doc":"Used in validators to return an error with a message","ref":"Validate.Validator.html#error/1"},{"type":"function","title":"Validate.Validator.halt/0","doc":"Used in validators to prevent further validation for a field but treated as a success","ref":"Validate.Validator.html#halt/0"},{"type":"function","title":"Validate.Validator.halt/1","doc":"Used in validators to prevent further validation for a field while also adding an error message","ref":"Validate.Validator.html#halt/1"},{"type":"function","title":"Validate.Validator.success/1","doc":"Used in validators to indicate validation was successful for a field","ref":"Validate.Validator.html#success/1"},{"type":"extras","title":"Validate","doc":"# Validate\n\nValidate data in elixir. Focused on validating incoming http request data but works with all elixir data types.\n\nComing from languages like PHP and Node.js it can be difficult to reason about validating your requests using Ecto. This provides a simple data validation layer that aims to be extensible to allow for custom validation logic provided by the user.\n\nInspired by Laravel's validator.","ref":"readme.html"},{"type":"extras","title":"Installation - Validate","doc":"Add Validate to your mix.exs dependencies:\n\n```elixir\ndefp deps do\n  [\n    {:validate, \"~> 1.3\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Features - Validate","doc":"- [x] Simple (raw string, bool, etc), nested maps, and list validation\n- [x] Built in validation rules\n- [x] Custom validation rules\n- [x] Return validated keys only\n- [x] Plug support\n- [ ] i18n","ref":"readme.html#features"},{"type":"extras","title":"Table of Contents - Validate","doc":"- [Installation](#installation)\n- [Usage](#usage)\n  - [Simple Validation](#simple-validation)\n  - [Map Validation](#map-validation)\n  - [Nested Rules](#nested-rules)\n- [Errors](#errors)\n  - [Formatting Errors](#formatting-errors)\n- [Custom Validation Rules](#custom-validation-rules)\n- [Plug](#plug)\n- [Built in Validation Rules](#built-in-validation-rules)","ref":"readme.html#table-of-contents"},{"type":"extras","title":"Usage - Validate","doc":"The basic usage looks like:\n\n```elixir\n# data is the validated input\n{:ok, data} = Validate.validate(input, rules)\n\n# errors is an array of %Validate.Validator.Error{}\n{:error, errors} = Validate.validate(input, rules)\n```\n\n#","ref":"readme.html#usage"},{"type":"extras","title":"Simple Validation - Validate","doc":"If you are validating a simple/flat data type (like string, boolean, number), you can simply pass the rules as a keyword list:\n\n```elixir\n{:ok, data} = Validate.validate(\"jane\", required: true, type: :string)\n```\n\n#","ref":"readme.html#simple-validation"},{"type":"extras","title":"Map Validation - Validate","doc":"If you are validating a map, such as the body of an incoming `post` request, you must pass a map of rules where the keys match the keys that you are validating. Note: the rule keys **must be the same type** as the data keys. If your data keys are strings, use string keys for the rules. If your data keys are atoms, use atoms for the rules. You can mix and match key types in the same map, as long as the keys in the rules mirror the keys in the data.\n\n```elixir\ninput = %{\n  \"email\" => \"test@example.com\",\n  \"age\" => 32\n}\n\nrules = %{\n  \"email\" => [required: true, type: :string],\n  \"age\" => [required: true, type: :number]\n}\n\n{:ok, data} = Validate.validate(input, rules)\n```\n\nImportant: The data returned from nested validations will always only be the keys specified in the rules. Any keys not specified in the rules are thrown away:\n\n```elixir\ninput = %{\n  \"url\" => \"https://google.com\",\n  \"friends\" => [\n    %{ \"name\" => \"Jane\", \"email\" => \"jane@example.com\" },\n  ],\n  \"age\" => 28\n}\n\nrules = %{\n  \"url\" => [required: true, type: :string],\n  \"friends\" => [\n    map: %{\n      \"name\" => [required: true, type: :string]\n    }\n  ]\n}\n\n{:ok, data} = Validate.validate(input, rules)\n\ndata == %{\n  \"url\" => \"https://google.com\",\n  \"friends\" => [\n    %{ \"name\" => \"Jane\"}\n  ]\n}\n```\n\n#","ref":"readme.html#map-validation"},{"type":"extras","title":"Nested Rules - Validate","doc":"You can also perform complex validation such as nested lists and maps:\n\n```elixir\ninput = %{\n  \"name\" => \"Jane Doe\",\n  \"colors\" => [\"red\", \"green\"],\n  \"address\" => %{\n    \"line1\" => \"123 Fake St\",\n    \"city\" => \"Saskatoon\"\n  },\n  \"friends\" => [\n    %{\"name\" => \"John\", \"email\" => \"john@example.com\"},\n    %{\"name\" => \"Michelle\", \"email\" => \"michelle@example.com\"}\n  ]\n}\n\nrules = %{\n  \"name\" => [required: true, type: :string],\n  \"colors\" => [\n    required: true,\n    type: :list,\n    list: [required: true, type: :string, in: ~w[blue orange red green purple]]\n  ],\n  \"address\" => [\n    required: true,\n    type: :map,\n    map: %{\n      \"line1\" => [required: true, type: :string],\n      \"city\" => [required: true, type: :string],\n    }\n  ],\n  \"friends\" => [\n    required: true,\n    type: :list,\n    list: [\n      required: true,\n      type: :map,\n      map: %{\n        \"name\" => [required: true, type: :string],\n        \"email\" => [required: true, type: :string]\n      }\n    ]\n  ]\n}\n\n{:ok, data} = Validate.validate(input, rules)\n```","ref":"readme.html#nested-rules"},{"type":"extras","title":"Errors - Validate","doc":"The error array returned contains `%Validate.Validator.Error{}` structs.\n\nWhen performing simple validations, `path` will be an empty array. When validating maps, `path` will be an array of keys representing the depth to get to the data value. For lists, the numeric index is used for the specific position of the error in the list.\n\n```elixir\n[\n  %Validate.Validator.Error{\n    path: [\"name\"],\n    message: \"is required\",\n    rule: :required\n  },\n  %Validate.Validator.Error{\n    path: [\"colors\", 2],\n    message: \"must be a string\",\n    rule: :type\n  },\n  %Validate.Validator.Error{\n    path: [\"address\", \"line1\"],\n    message: \"is required\",\n    rule: :required\n  },\n]\n```\n\n#","ref":"readme.html#errors"},{"type":"extras","title":"Formatting Errors - Validate","doc":"Sometimes it is easier to show errors to the user by name instead of looping through the array, so a helper is provided to make this easy:\n\n```elixir\n# assuming the error array from the above example\nformatted = Validate.Util.errors_to_map(errors)\n\nformatted == %{\n  \"name\" => [\"is required\"],\n  \"colors.2\" => [\"must be a string\"],\n  \"address.line1\" => [\"is required\"]\n}\n```","ref":"readme.html#formatting-errors"},{"type":"extras","title":"Custom Validation Rules - Validate","doc":"You can write your own validators by using the `custom:` rule. You can write these as modules or as inline functions.\n\nValidation rules must return one of four possible outcomes:\n\n- `Validate.Validator.success(value)` - Return this when validation passes. You must pass the value back as the first arg. This gives you the opportunity to transform the value if you wish.\n- `Validate.Validator.error(message)` - Return this when validation fails. You must pass a message back to the user to let them know why it failed.\n- `Validate.Validator.halt(message)` - Return this when validation fails AND you want to prevent any further validation from running on this specific input.\n- `Validate.Validator.halt()` - Return this when validation succeeds BUT you do not want any further validations to happen on this specific input.\n\nFor example, we could write a custom rule to see if an email already exists in our database:\n\n```elixir\ninput = %{\n  \"email\" => \"hello@example.com\"\n}\n\nrules = %{\n  \"email\" => [\n    required: true,\n    type: :string,\n    custom: fn %{ value: value } ->\n      if MyApp.Accounts.email_exists?(value) do\n        Validate.Validator.error(\"email is already taken\")\n      else\n        Validate.Validator.success(value)\n      end\n    end\n  ]\n}\n```\n\nIf you'd like to have the rule be reusable, you could move it into a module. For further readability, you could also make it a higher-order function to prevent passing function references like `&MyApp.MyRule.validate/1`:\n\n```elixir\ndefmodule MyApp.EmailExists do\n  def validate() do\n    fn %{ value: value } ->\n      if MyApp.Accounts.email_exists?(value) do\n        Validate.Validator.error(\"email is already taken\")\n      else\n        Validate.Validator.success(value)\n      end\n    end\n  end\nend\n\n\ninput = %{\n  \"email\" => \"hello@example.com\"\n}\n\nrules = %{\n  \"email\" => [\n    required: true,\n    type: :string,\n    custom: MyApp.EmailExists.validate(),\n  ]\n}\n```","ref":"readme.html#custom-validation-rules"},{"type":"extras","title":"Plug - Validate","doc":"You can use Validate as a plug to simplify your controllers by performing validation and authorization outside of your controller action.\n\nFirst you need to create a file in your project for the plug. This is required so that you can control what happens when different events occur. Some applications may wish to return JSON, while others want to redirect to a route. Providing this as a macro in your own application gives you the flexibility to handle this how you please.\n\nFor this example, we'll create a file called `my_app_web/plugs/form_request.ex`\n\n```elixir\ndefmodule MyAppWeb.Plugs.FormRequest do\n  use Validate.Plugs.FormRequest,\n    validate_success: :validate_success,\n    validate_error: :validate_error,\n    auth_error: :auth_error\n\n  import Plug.Conn\n\n  # called when validation passess\n  # use this to make the validated data available to your controller\n  def validate_success(conn, data) do\n    conn |> assign(:validated, data)\n  end\n\n  def validate_error(conn, errors) do\n    error_map = Validate.Util.errors_to_map(errors)\n    conn |> put_status(422) |> Phoenix.Controller.json(%{errors: error_map}) |> halt()\n  end\n\n  def auth_error(conn) do\n    conn |> put_status(401) |> Phoenix.Controller.json(%{message: \"unauthorized\"}) |> halt()\n  end\nend\n```\n\nNow we can create a module that will handle the request. This module can exist anywhere but needs to implement at least a `rules/1` function and optionally an `authorize/1` function. `authorize/1` will be called first if it is present, and only if it returns a truthy value will it continue to validate the input, if it returns a falsy value we will call the `auth_error` function in our plug from earlier. `rules/1` should return a map of rules that will be validated against `conn.params`.\n\nLet's pretend we're making a form to create a team in our application. We might put this in `my_app_web/requests/store_team_request.ex`.\n\n```elixir\ndefmodule MyAppWeb.Requests.StoreTeamRequest do\n  # can only create a team if we do not already have a team\n  def authorize(conn) do\n    conn.assigns.user && !conn.assigns.team\n  end\n\n  def rules(_conn) do\n    %{\n      \"name\" => [required: true, type: :string, max: 80],\n      \"plan\" => [required: true, type: :string, in: [\"free\", \"pro\"]],\n      # ...\n    }\n  end\nend\n```\n\nNow we're ready to use this in our controller. Let's assume we have a controller like `my_app_web/controllers/team_controller.ex`.\n\n```elixir\ndefmodule MyAppWeb.Controllers.TeamController do\n  use MyAppWeb, :controller\n\n  plug MyAppWeb.Plugs.FormRequest, MyAppWeb.Requests.StoreTeamRequest when action in [:store]\n\n  def store(conn, params) do\n    # now we can operate in here knowing that\n    # our request is authorized and the validated data\n    # is in conn.assigns.validated\n  end\nend\n```\n\nThe controller can be registered like normal in your routes file, and the plug will take care of authorizing and validating before calling the controller action!\n\n```elixir\n# inside your routes file somewhere\nscope \"/\" do\n  pipe_through [:browser]\n\n  post \"/teams\", MyAppWeb.Controllers.TeamController, :store\nend\n```\n\nIf you wanted, you could bypass the controller all together by adding a `perform/2` function to the request module and just handle the request right there:\n\n```elixir\ndefmodule MyAppWeb.Requests.StoreTeamRequest do\n  def rules(_conn) do\n    %{\n      \"name\" => [required: true, type: :string, max: 80],\n      # ...\n    }\n  end\n\n  def perform(conn, data) do\n    # skip the controller and just handle the request here\n    # `data` is the validated data\n  end\nend\n\n# then in your router file\nscope \"/\" do\n  pipe_through [:browser]\n\n  post \"/teams\", MyAppWeb.Plugs.FormRequest, MyAppWeb.Requests.StoreTeamRequest\nend\n```\n\nIf you choose to use `perform/2` then the `validate_success` option provided in `plugs/form_request.ex` will be ignored for that request.","ref":"readme.html#plug"},{"type":"extras","title":"Built in Validation Rules - Validate","doc":"Examples show input that would successfully validate. Some rules require a type to be specified first in order to properly validate.\n\n- [comparison operators (==, >, >=, <, <=)](#comparison-operators)\n- [between](#between)\n- [cast](#cast)\n- [characters](#characters)\n- [date_string](#date_string)\n- [digits_between](#digits_between)\n- [digits](#digits)\n- [ends_with](#ends_with)\n- [in](#in)\n- [ip/v4/v6](#ip)\n- [lowercase](#lowercase)\n- [max_digits](#max_digits)\n- [max](#max)\n- [min_digits](#min_digits)\n- [min](#min)\n- [not_ends_with](#not_ends_with)\n- [not_in](#not_in)\n- [not_regex](#not_regex)\n- [not_starts_with](#not_starts_with)\n- [nullable](#nullable)\n- [regex](#regex)\n- [required](#required)\n- [size](#size)\n- [starts_with](#starts_with)\n- [type](#type)\n- [uppercase](#uppercase)\n- [url](#url)\n- [uuid](#uuid)\n\n#","ref":"readme.html#built-in-validation-rules"},{"type":"extras","title":"comparison operators - Validate","doc":"You can use atoms of `==`, `>`, `>=`, `<`, and `<=` to compare values.\n\nAside from primitive values you can compare Date, DateTime, and NaiveDateTime values.\n\n```elixir\nValidate.validate(\"bob\", ==: \"bob\")\n\nValidate.validate(~D[2020-02-15], >: ~D[2015-10-14])\n```\n\n#","ref":"readme.html#comparison-operators"},{"type":"extras","title":"between - Validate","doc":"The field under validation must be between the two numbers (inclusive).\n\n```elixir\nValidate.validate(10, type: :number, between: {1, 20})\n```\n\n#","ref":"readme.html#between"},{"type":"extras","title":"cast - Validate","doc":"Trys to convert the field to the specified type. Can be used in place of the [`type`](#type) rule if you e.g. want a number as the end result but are taking input from an HTML form which is inputted as a string. Later validation rules and the resulting validated data will contain the casted value in the new type. Prevents further rules from running if validation fails.\n\nAvailable types are: `:atom`, `:boolean`, `:float`, `:integer`, `:string`.\n\n```elixir\nValidate.validate(\"123\", cast: :integer)\n```\n\n`nil` is converted to the appropriate \"empty\" value of the type:\n\n- `:atom` -> `:\"\"`\n- `:boolean` -> `false`\n- `:float` -> `0.0`\n- `:integer` -> `0`\n- `:string` -> `\"\"`\n\nIf you'd like to preserve `nil` you must use the full syntax and pass the `:preserve` flag:\n\n```elixir\nValidate.validate(nil, cast: [to: :integer, nil: :preserve])\n```\n\n#","ref":"readme.html#cast"},{"type":"extras","title":"characters - Validate","doc":"The field under validation must have a specific set of characters. Useful for things like usernames.\n\n```elixir\n# letters only\nValidate.validate(\"LeslieKnope\", type: :string, characters: :alpha)\n\n# letters + numbers\nValidate.validate(\"LeslieKnope123\", type: :string, characters: :alpha_num)\n\n# letters, numbers, dashes, underscores\nValidate.validate(\"Leslie-Knope_123\", type: :string, characters: :alpha_dash)\n```\n\nEach option also has an `_ascii` alternative available to restrict any non-ascii characters: `:alpha_ascii`, `:alpha_num_ascii`, `:alpha_dash_ascii`.\n\n#","ref":"readme.html#characters"},{"type":"extras","title":"date_string - Validate","doc":"The field under validation must be a string matching a valid Timex string format.\n\n```elixir\nValidate.validate(\"2020-02-10\", date_string: \"{YYYY}-{0M}-{0D}\")\n```\n\n#","ref":"readme.html#date_string"},{"type":"extras","title":"digits_between - Validate","doc":"The field under validation must have a number of digits between the two numbers (inclusive).\n\n```elixir\nValidate.validate(100, type: :integer, digits_between: {2, 4})\n```\n\n#","ref":"readme.html#digits_between"},{"type":"extras","title":"digits - Validate","doc":"The field under validation must have the exact amount of digits.\n\n```elixir\nValidate.validate(100, type: :integer, digits: 3)\n```\n\n#","ref":"readme.html#digits"},{"type":"extras","title":"ends_with - Validate","doc":"The field under validation must end with the specified string.\n\n```elixir\nValidate.validate(\"exciting!\", type: :string, ends_with: \"!\")\n```\n\n#","ref":"readme.html#ends_with"},{"type":"extras","title":"in - Validate","doc":"The field under validation must be in the provided array.\n\n```elixir\nValidate.validate(\"blue\", type: :string, in: [\"red\", \"green\", \"blue\"])\n```\n\n#","ref":"readme.html#in"},{"type":"extras","title":"ip - Validate","doc":"The field under validation must be a valid IP address.\n\n```elixir\n# allows v4 or v6\nValidate.validate(\"127.0.0.1\", type: :string, ip: true)\n\n# v4 only\nValidate.validate(\"127.0.0.1\", type: :string, ip: :v4)\n\n# v6 only\nValidate.validate(\"3ffe:b80:1f8d:2:204:acff:fe17:bf3\", type: :string, ip: :v6)\n```\n\n#","ref":"readme.html#ip"},{"type":"extras","title":"lowercase - Validate","doc":"The field under validation must be all lowercase.\n\n```elixir\nValidate.validate(\"hello\", type: :string, lowercase: true)\n```\n\nThe field under validation must not be all lowercase.\n\n```elixir\nValidate.validate(\"Hello\", type: :string, lowercase: false)\n```\n\n#","ref":"readme.html#lowercase"},{"type":"extras","title":"list - Validate","doc":"The field under validation must be a list, and you must specify rules that should be ran for each item in the list.\n\n```elixir\nValidate.validate([1, 2, 3], list: [required: true, type: :number])\n```\n\n#","ref":"readme.html#list"},{"type":"extras","title":"map - Validate","doc":"The field under validation must be a map, and you must specify validation rules for the keys of the map.\n\n```elixir\nValidate.validate(%{\"name\" => \"Jane\"}, map: %{\"name\" => [required: true, type: :string]})\n\n# you can also just pass a map directly as the second argument when the input is a map\nValidate.validate(%{\"name\" => \"Jane\"}, %{\"name\" => [required: true, type: :string]})\n\n# nesting also works\nValidate.validate(%{\n  \"address\" => %{\n    \"line1\" => \"123 Fake st\"\n  }\n}, %{\n  \"address\" => [\n    map: %{\n      \"line1\" => [\n        required: true,\n        type: :string\n      ]\n    }\n  ]\n})\n```\n\n#","ref":"readme.html#map"},{"type":"extras","title":"max_digits - Validate","doc":"The field under validation must be at most the provided number of digits.\n\n```elixir\nValidate.validate(10, type: :integer, max_digits: 2)\n```\n\n#","ref":"readme.html#max_digits"},{"type":"extras","title":"max - Validate","doc":"The field under validation must be less than or equal to the provided number.\n\n```elixir\nValidate.validate(10, type: :number, max: 15)\n```\n\n#","ref":"readme.html#max"},{"type":"extras","title":"min_digits - Validate","doc":"The field under validation must be at least the provided number of digits.\n\n```elixir\nValidate.validate(10, type: :integer, min_digits: 2)\n```\n\n#","ref":"readme.html#min_digits"},{"type":"extras","title":"min - Validate","doc":"The field under validation must be greater than or equal to the provided number.\n\n```elixir\nValidate.validate(10, type: :number, min: 1)\n```\n\n#","ref":"readme.html#min"},{"type":"extras","title":"not_ends_with - Validate","doc":"The field under validation must not end with the provided string.\n\n```elixir\nValidate.validate(\"exciting\", type: :string, not_ends_with: \"!\")\n```\n\n#","ref":"readme.html#not_ends_with"},{"type":"extras","title":"not_in - Validate","doc":"The field under validation must not be in the provided array.\n\n```elixir\nValidate.validate(\"black\", type: :string, not_in: [\"red\", \"green\", \"blue\"])\n```\n\n#","ref":"readme.html#not_in"},{"type":"extras","title":"not_regex - Validate","doc":"The field under validation must not match the provided pattern.\n\n```elixir\nValidate.validate(\"abcd\", type: :string, not_regex: ~r/[0-9]/)\n```\n\n#","ref":"readme.html#not_regex"},{"type":"extras","title":"not_starts_with - Validate","doc":"The field under validation must not start with the provided string.\n\n```elixir\nValidate.validate(\"company_123\", type: :string, not_starts_with: \"user_\")\n```\n\n#","ref":"readme.html#not_starts_with"},{"type":"extras","title":"nullable - Validate","doc":"The field under validation can be `nil`. If the value is `nil`, it does not process any more rules for the field.\n\n```elixir\n# type & min do not run here\nValidate.validate(nil, nullable: true, type: :string, min: 10)\n```\n\n#","ref":"readme.html#nullable"},{"type":"extras","title":"regex - Validate","doc":"The field under validation must match the provided pattern.\n\n```elixir\nValidate.validate(\"1234\", type: :string, regex: ~r/[0-9]/)\n```\n\n#","ref":"readme.html#regex"},{"type":"extras","title":"required - Validate","doc":"The field under validation must not be empty.\n\nEmpty values are `nil`, `\"\"`, `%{}`, `[]`, `{}`.\n\n```elixir\nValidate.validate(\"red\", required: true)\n```\n\nIf set to `required: false`, empty values will be accepted.\n\n```elixir\nValidate.validate(\"\", required: false)\n```\n\nThis can be used as a \"required if\" by evaluating a statement to a boolean:\n\n```elixir\nValidate.validate(\"red\", required: check_if_color_is_needed())\n```\n\n#","ref":"readme.html#required"},{"type":"extras","title":"size - Validate","doc":"The field under validation must have a size matching the given value.\n\n- Numbers are compared directly to the value\n- String sizes are calculated with `String.length/1`\n- List and map sizes are calculated with `Enum.count/1`\n- Tuple sizes are calculated with `tuple_size/1`\n\n```elixir\nValidate.validate(\"123\", size: 3)\nValidate.validate(10, size: 10)\nValidate.validate([1, 2, 3], size: 3)\nValidate.validate(%{ ok: true }, size: 1)\nValidate.validate({1, 2}, size: 2)\n```\n\n#","ref":"readme.html#size"},{"type":"extras","title":"starts_with - Validate","doc":"The field under validation must start with the given value.\n\n```elixir\nValidate.validate(\"user_1234\", type: :string, starts_with: \"user_\")\n```\n\n#","ref":"readme.html#starts_with"},{"type":"extras","title":"type - Validate","doc":"The field under validation must be of the specified type.\n\nValid types are: `atom`, `binary`, `boolean`, `date`, `datetime`, `float`, `function`, `integer`, `list`, `map`, `naive_datetime`, `number`, `string`, `tuple`.\n\n```elixir\nValidate.validate(:user, type: :atom)\n```\n\n#","ref":"readme.html#type"},{"type":"extras","title":"uppercase - Validate","doc":"The field under validation must be all uppercase.\n\n```elixir\nValidate.validate(\"HELLO\", type: :string, uppercase: true)\n```\n\nThe field under validation must not be all uppercase.\n\n```elixir\nValidate.validate(\"hEllO\", type: :string, uppercase: false)\n```\n\n#","ref":"readme.html#uppercase"},{"type":"extras","title":"url - Validate","doc":"The field under validation must be a valid url. Evaluated using `URI.new/1` and requires that the url has scheme (such as `http://`).\n\n```elixir\nValidate.validate(\"https://example.com\", type: :string, url: true)\n```\n\n#","ref":"readme.html#url"},{"type":"extras","title":"uuid - Validate","doc":"The field under validation must be a uuid.\n\n```elixir\nValidate.validate(\"123e4567-e89b-12d3-a456-426655440000\", type: :string, uuid: true)\n```","ref":"readme.html#uuid"}],"content_type":"text/markdown"}